@@ -7,6 +7,7 @@ use File::Basename qw(dirname);
 use Cwd qw(abs_path);
 use Test::TempDatabase;
 use File::Slurp;
+use Apache::SWIT::Test::Utils;
 
 sub Check_For_Run_Server {
 	my $argv = shift;
@@ -32,26 +33,34 @@ sub swit_run {
 }
 
 sub run_tests {
-	return shift()->SUPER::run_tests(@_)
-		unless $ENV{__APACHE_SWIT_RUN_SERVER__};
-	print STDERR "# Server url is http://"
-			. Apache::TestRequest::hostport ."\n";
-	print STDERR "# Press Enter to finish ...\n";
-	readline(\*STDIN);
+	my $res = 0;
+	ASTU_Mem_Show("Apache memory before");
+	if ($ENV{__APACHE_SWIT_RUN_SERVER__}) {
+		print STDERR "# Server url is http://"
+				. Apache::TestRequest::hostport ."\n";
+		print STDERR "# Press Enter to finish ...\n";
+		readline(\*STDIN);
+	} else {
+		$res = shift()->SUPER::run_tests(@_);
+	}
+	ASTU_Mem_Show("Apache memory after");
+	return $res;
 }
 
 sub configure {
 	shift()->SUPER::configure(@_);
-	return unless $ENV{APACHE_SWIT_PROFILE};
 	my $cf = read_file('t/conf/httpd.conf');
-	$cf =~ s/PerlSwitches/#/g;
-	write_file('t/conf/httpd.conf', "$cf\n" . <<ENDS);
-<Perl>
-        require Apache::DB;
-        Apache::DB->init;
-</Perl>
-PerlModule Apache::DProf
+	$cf =~ s/TransferLog/#/g;
+	if ($ENV{APACHE_SWIT_PROFILE}) {
+		mkdir 't/logs';
+		my $abs = abs_path('t/logs');
+		$cf .= <<ENDS;
+PerlSetEnv NYTPROF file=$abs/nytprof
+PerlModule Devel::NYTProf::Apache
+MaxClients 1
 ENDS
+	}
+	write_file('t/conf/httpd.conf', $cf);
 }
 
 1;
